@@ -1,7 +1,7 @@
 package MooseX::Workers;
 use Moose::Role;
 use MooseX::Workers::Job;
-our $VERSION = '0.15';      # http://www.cpan.org/modules/04pause.html - Developer releases
+our $VERSION = '0.16';      # http://www.cpan.org/modules/04pause.html - Developer releases
 
 use MooseX::Workers::Engine;
 
@@ -134,7 +134,7 @@ MooseX::Workers - Simple sub-process management for asynchronous tasks
                 sleep 3;
 
                 #    Return a hashref (arrayref, whatever) to the parent using P::F::Reference
-                print POE::Filter::Reference->new->put([ {msg => "Hello World"} ]); # Note the [] around the return val
+                print @{POE::Filter::Reference->new->put([ {msg => "Hello World"} ])}; # Note the [] around the return val
 
                 #    Print normally using P::F::Line (shown for
                 #    completeness; in practice, just don't bother
@@ -150,8 +150,8 @@ MooseX::Workers - Simple sub-process management for asynchronous tasks
     # Implement our Interface
     #    These two are both optional; if defined (as here), they
     #    should return a subclass of POE::Filter.
-    sub stdout_filter  { new POE::Filter::Reference }
-    sub stderr_filter  { new POE::Filter::Line }
+    sub stdout_filter  { POE::Filter::Reference->new }
+    sub stderr_filter  { POE::Filter::Line->new }
 
     sub worker_stdout  {  
         my ( $self, $result ) = @_;  #  $result will be a hashref:  {msg => "Hello World"} 
@@ -184,7 +184,7 @@ MooseX::Workers - Simple sub-process management for asynchronous tasks
 =head1 DESCRIPTION
 
 MooseX::Workers is a Role that provides easy delegation of long-running tasks 
-into a managed child process. Process managment is taken care of via POE and it's 
+into a managed child process. Process management is taken care of via POE and its 
 POE::Wheel::Run module.
 
 =head1 METHODS
@@ -201,9 +201,9 @@ These three methods are the whole point of this module.
 They pass $command through to the MooseX::Worker::Engine which will take 
 care of running $command for you.
 
-spawn() and fork() both envoke L<POE::Kernel> call(), which is synchronous.
+spawn() and fork() both invoke L<POE::Kernel> call(), which is synchronous.
 
-run_command() envokes L<POE::Kernel> yield(), which is asynchronous.
+run_command() invokes L<POE::Kernel> yield(), which is asynchronous.
 
 If max_workers() has been reached, run_command() warns and does nothing. It is up to you to re-submit
 $command. See enqueue() if you want us to run $command as soon as another worker is free.
@@ -221,7 +221,7 @@ if the $num_workers is >= $max_workers;
 
 =item max_workers($count)
 
-An accessor for the maxium number of workers. This is delegated to the MooseX::Workers::Engine object.
+An accessor for the maximum number of workers. This is delegated to the MooseX::Workers::Engine object.
 
 =item has_workers
 
@@ -295,7 +295,7 @@ Called when a worker starts $command
 
 =item sig_child
 
-Called when the mangaging session recieves a SIG CHDL event
+Called when the mangaging session recieves a SIG CHLD event
 
 =item sig_*
 
@@ -322,26 +322,17 @@ Also see L<MooseX::Workers::Job> if you'd like to give your tasks
 names, or set timeouts on them.
 
 
-=head1 CONFIGURATION AND ENVIRONMENT
-
-MooseX::Workers requires no configuration files or environment variables.
-
 =head1 DEPENDENCIES
 
 Moose, POE, POE::Wheel::Run
 
-=head1 INCOMPATIBILITIES
-
-None reported.
-
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
 Please report any bugs or feature requests to
 C<bug-moosex-workers@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
+Version control: L<https://github.com/jhannah/moosex-workers>
 
 =head1 AUTHORS
 
@@ -358,7 +349,7 @@ David K. Storrs C<< <david.storrs@gmail.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007-2010, Chris Prather C<< <perigrin@cpan.org> >>. Some rights reserved.
+Copyright (c) 2007-2011, Chris Prather C<< <perigrin@cpan.org> >>. Some rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
